@@ -1,4 +1,4 @@
-package Net::FullAuto::ISets::Local::WordPress_is;
+package Net::FullAuto::ISets::Local::PHP_is;
 
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
@@ -35,7 +35,7 @@ my $service_and_cert_password='Full@ut0O1';
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw($select_wordpress_setup);
+our @EXPORT = qw($select_php_setup);
 
 use Net::FullAuto::Cloud::fa_amazon;
 use Net::FullAuto::FA_Core qw[$localhost cleanup fetch clean_filehandle];
@@ -73,10 +73,10 @@ my $builddir='';my @ls_tmp=();
 
 # MENU Log-In Log-Out
 # https://premium.wpmudev.org/blog/
-# how-to-add-a-loginlogout-link-to-your-wordpress-menu/
-# http://vanweerd.com/enhancing-your-wordpress-3-menus/#add_login
+# how-to-add-a-loginlogout-link-to-your-php-menu/
+# http://vanweerd.com/enhancing-your-php-3-menus/#add_login
 
-# wp plugin list --path=/var/www/html/wordpress --status=active --allow-root
+# wp plugin list --path=/var/www/html/php --status=active --allow-root
 
 # https://www.digitalocean.com/community/tutorials/
 # how-to-set-up-a-firewall-using-firewalld-on-centos-7
@@ -88,7 +88,7 @@ my $builddir='';my @ls_tmp=();
 
 # https://www.cartoonify.de/
 
-my $configure_wordpress=sub {
+my $configure_php=sub {
 
    my $selection=$_[0]||'';
    my $domain_url=$_[1]||'';
@@ -551,9 +551,9 @@ END
 
 };
 
-my $standup_wordpress=sub {
+my $standup_php=sub {
 
-   my $catalyst="]T[{select_wordpress_setup}";
+   my $catalyst="]T[{select_php_setup}";
    my $password="]I[{'enter_password',1}";
    my $email_address="]I[{'email_address',1}";
    my $stripe_pub="]I[{'stripe_keys',1}";
@@ -562,384 +562,41 @@ my $standup_wordpress=sub {
    my $recaptcha_sec="]I[{'recaptcha_keys',2}";
    my $domain_url="]I[{'domain_url',1}";
    my $cnt=0;
-   $configure_wordpress->($catalyst,$domain_url,$password,$email_address,$stripe_pub,
+   $configure_php->($catalyst,$domain_url,$password,$email_address,$stripe_pub,
                           $stripe_sec,$recaptcha_pub,$recaptcha_sec);
    return '{choose_demo_setup}<';
 
 };
 
-my $wordpress_setup_summary=sub {
+our $select_php_setup=sub {
 
-   package wordpress_setup_summary;
-   use JSON::XS;
-   my $region="]T[{awsregions}";
-   $region=~s/^"//;
-   $region=~s/"$//;
-   my $type="]T[{select_type}";
-   $type=~s/^"//;
-   $type=~s/"$//;
-   my $money=$type;
-   $money=~s/^.*-> \$(.*?) +(?:[(].+[)] )*\s*per hour$/$1/;
-   $type=substr($type,0,(index $type,' ->')-3);
-   my $catalyst="]T[{select_wordpress_setup}";
-   $catalyst=~s/^"//;
-   $catalyst=~s/"$//;
-   print "REGION=$region and TYPE=$type\n";
-   print "CATALYST=$catalyst\n";
-   my $num_of_servers=0;
-   my $ol=$catalyst;
-   $ol=~s/^.*(\d+)\sServer.*$/$1/;
-   if ($ol==1) {
-      $main::aws->{'CatalystFramework.org'}->[0]=[];
-   } elsif ($ol=~/^\d+$/ && $ol) {
-      foreach my $n (0..$ol) {
-         $main::aws->{'CatalystFramework.org'}=[] unless exists
-            $main::aws->{'CatalystFramework.org'};
-         $main::aws->{'CatalystFramework.org'}->[$n]=[];
-      }
-   }
-   $num_of_servers=$ol;
-   my $cost=int($num_of_servers)*$money;
-   my $cents='';
-   if ($cost=~/^0\./) {
-      $cents=$cost;
-      $cents=~s/^0\.//;
-      if (length $cents>2) {
-         $cents=~s/^(..)(.*)$/$1.$2/;
-         $cents=~s/^0//;
-         $cents=' ('.$cents.' cents)';
-      } else {
-         $cents=' ('.$cents.' cents)';
-      }
-   }
-   my $show_cost_banner=<<'END';
+   my @options=('PHP on This Host');
+   my $php_setup_banner=<<'END';
 
-      _                  _       ___        _  ___
-     /_\  __ __ ___ _ __| |_    / __|___ __| ||__ \
-    / _ \/ _/ _/ -_) '_ \  _|  | (__/ _ (_-<  _|/_/
-   /_/ \_\__\__\___| .__/\__|   \___\___/__/\__(_)
-                   |_|
+    ____  _   _ ____
+   |  _ \| | | |  _ \
+   | |_) | |_| | |_) |
+   |  __/|  _  |  __/
+   |_|   |_| |_|_|
+
+
+   Choose the PHP setup you wish to install on this localhost:
 
 END
-   $show_cost_banner.=<<END;
-   Note: There is a \$$cost per hour cost$cents to launch $num_of_servers
-         AWS EC2 $type servers for the FullAuto Demo:
+   my %select_php_setup=(
 
-         $catalyst
-
-
-END
-   my %show_cost=(
-
-      Name => 'show_cost',
-      Item_1 => {
-
-         Text => "I accept the \$$cost$cents per hour cost",
-         Result => $standup_wordpress,
-
-      },
-      Item_2 => {
-
-         Text => "Return to Choose Demo Menu",
-         Result => sub { return '{choose_demo_setup}<' },
-
-      },
-      Item_3 => {
-
-         Text => "Exit FullAuto",
-         Result => sub { cleanup() },
-
-      },
-      Scroll => 1,
-      Banner => $show_cost_banner,
-
-   );
-   return \%show_cost;
-
-};
-
-our $recaptcha_keys=sub {
-
-   package recaptcha_keys;
-   my $password_banner=<<'END';
-
-             ___           _      _           _  __
-    _ _ ___ / __|__ _ _ __| |_ __| |_  __ _  | |/ /___ _  _ ___
-   | '_/ -_) (__/ _` | '_ \  _/ _| ' \/ _` | | ' </ -_) || (_-<
-   |_| \___|\___\__,_| .__/\__\__|_||_\__,_| |_|\_\___|\_, /__/
-                     |_|                               |__/
-
-END
-   $password_banner.=<<END;
-   Paste the necessary reCaptcha Keys here:
-
-   *** BE SURE TO WRITE IT DOWN AND KEEP IT SOMEWHERE SAFE! ***
-
-   Input box with === border is highlighted (active) input box.
-   Use [TAB] key to switch focus between input boxes.
-
-
-   Publish Key
-                ]I[{1,'',46}
-
-   Secret Key
-                ]I[{2,'',46}
-END
-
-   my $recaptcha_keys={
-
-      Name => 'recaptcha_keys',
-      Input => 1,
-      Result => $standup_wordpress,
-      #Result =>
-   #$Net::FullAuto::ISets::Local::WordPress_is::select_wordpress_setup,
-      Banner => $password_banner,
-
-   };
-   return $recaptcha_keys;
-
-};
-
-our $stripe_keys=sub {
-
-   package stripe_keys;
-   my $password_banner=<<'END';
-
-    ___ _       _             _  __
-   / __| |_ _ _(_)_ __  ___  | |/ /___ _  _ ___
-   \__ \  _| '_| | '_ \/ -_) | ' </ -_) || (_-<
-   |___/\__|_| |_| .__/\___| |_|\_\___|\_, /__/
-                 |_|                   |__/
-
-END
-   $password_banner.=<<END;
-   Paste the necessary Stripe Account Keys here:
-
-   *** BE SURE TO WRITE IT DOWN AND KEEP IT SOMEWHERE SAFE! ***
-
-   Input box with === border is highlighted (active) input box.
-   Use [TAB] key to switch focus between input boxes.
-
-
-   Publish Key 
-                ]I[{1,'',46}
-
-   Secret Key
-                ]I[{2,'',46}
-END
-
-   my $stripe_keys={
-
-      Name => 'stripe_keys',
-      Input => 1,
-      Result => $recaptcha_keys,
-      #Result =>
-   #$Net::FullAuto::ISets::Local::WordPress_is::select_wordpress_setup,
-      Banner => $password_banner,
-
-   };
-   return $stripe_keys;
-
-};
-
-our $email_address=sub {
-
-   package email_address;
-   my $email_banner=<<'END';
-
-    ___            _ _     _      _    _
-   | __|_ __  __ _(_) |   /_\  __| |__| |_ _ ___ ______
-   | _|| '  \/ _` | | |  / _ \/ _` / _` | '_/ -_|_-<_-<
-   |___|_|_|_\__,_|_|_| /_/ \_\__,_\__,_|_| \___/__/__/
-
-END
-   $email_banner.=<<END;
-   Type or Paste the necessary Email Address for WordPress here:
-
-   Input box with === border is highlighted (active) input box.
-   Use [TAB] key to switch focus between input boxes.
-
-
-   Email Address
-                   ]I[{1,'brian.kelly\@fullauto.com',45}
-
-   Confirm Address
-                   ]I[{2,'brian.kelly\@fullauto.com',45}
-END
-
-   my $email_address={
-
-      Name => 'email_address',
-      Input => 1,
-      Result => $stripe_keys,
-      #Result =>
-   #$Net::FullAuto::ISets::Local::WordPress_is::select_wordpress_setup,
-      Banner => $email_banner,
-
-   };
-   return $email_address;
-
-};
-
-our $choose_strong_password=sub {
-
-   package choose_strong_password;
-   my $password_banner=<<'END';
-
-    ___ _                       ___                              _
-   / __| |_ _ _ ___ _ _  __ _  | _ \__ _ _______ __ _____ _ _ __| |
-   \__ \  _| '_/ _ \ ' \/ _` | |  _/ _` (_-<_-< V  V / _ \ '_/ _` |
-   |___/\__|_| \___/_||_\__, | |_| \__,_/__/__/\_/\_/\___/_| \__,_|
-                        |___/
-END
-
-   use Crypt::GeneratePassword qw(chars);
-   my $minlen=15;
-   my $maxlen=15;
-   my @set=("A".."Z","a".."z",0..9,"#","-","_","@","%","^","=");
-   my $word='';
-   foreach my $count (1..50) {
-      print "\n   Generating Password ...\n";
-      $word=eval {
-         local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
-         alarm 7;
-         my $word=chars($minlen,$maxlen,\@set);
-         print "\n   Trying Password - $word ...\n";
-         die if -1<index $word,'*';
-         die if -1<index $word,'$';
-         die if -1<index $word,'+';
-         die if -1<index $word,'&';
-         die if -1<index $word,'/';
-         die if -1<index $word,'!';
-         die if -1<index $word,'^';
-         die if $word!~/\d/;
-         die if $word!~/[A-Z]/;
-         die if $word!~/[a-z]/;
-         die if $word!~/[@#%=]/;
-         return $word;
-      };
-      alarm 0;
-      last if $word;
-   }
-   $password_banner.=<<END;
-   The Web Server (NGINX) and the SSL Certificate each need a strong password.
-   Use the one supplied here, or create your own. To create your own, use the
-   [DEL] key to clear the highlighted input box first.
-
-   *** BE SURE TO WRITE IT DOWN AND KEEP IT SOMEWHERE SAFE! ***
-
-   Input box with === border is highlighted (active) input box.
-   Use [TAB] key to switch focus between input boxes.
-
-   Password
-                    ]I[{1,\'$word\',50}
-
-   Confirm
-                    ]I[{2,\'$word\',50}
-
-
-END
-   my $enter_password={
-
-      Name => 'enter_password',
-      Input => 1,
-      Result => $email_address,
-      #Result =>
-   #$Net::FullAuto::ISets::Local::WordPress_is::select_wordpress_setup,
-      Banner => $password_banner,
-
-   };
-   return $enter_password;
-
-};
-
-our $domain_url=sub {
-
-   package domain_url;
-   use Net::FullAuto;
-   my $handle=connect_shell();
-   my ($stdout,$stderr)=$handle->cmd("wget -qO- http://icanhazip.com");
-   my $public_ip=$stdout if $stdout=~/^\d+\.\d+\.\d+\.\d+\s*/s;
-   unless ($public_ip) {
-      require Sys::Hostname;
-      import Sys::Hostname;
-      require Socket;
-      import Socket;
-      my($addr)=inet_ntoa((gethostbyname(Sys::Hostname::hostname))[4]);
-      $public_ip=$addr if $addr=~/^\d+\.\d+\.\d+\.\d+\s*/s;
-   }
-   chomp($public_ip);
-   $public_ip='127.0.0.1' unless $public_ip;
-
-   my $domain_url_banner=<<'END';
-
-    ___                 _        _   _ ___ _
-   |   \ ___ _ __  __ _(_)_ _   | | | | _ \ |
-   | |) / _ \ '  \/ _` | | ' \  | |_| |   / |__
-   |___/\___/_|_|_\__,_|_|_||_|  \___/|_|_\____|
-
-
-END
-   $domain_url_banner.=<<END;
-   Type or paste the domain url for the site:
-
-   *** A properly registered domain url is necessary! ***
-
-   Make sure the DNS A/AAAA record(s) for this domain
-   contain(s) this IP address --> $public_ip
-
-
-   Domain URL
-                ]I[{1,'fullauto.com',46}
-
-END
-
-   my $domain_url={
-
-      Name => 'domain_url',
-      Input => 1,
-      Result => $choose_strong_password,
-      #Result =>
-   #$Net::FullAuto::ISets::Local::WordPress_is::select_wordpress_setup,
-      Banner => $domain_url_banner,
-
-   };
-   return $domain_url;
-
-};
-
-our $select_wordpress_setup=sub {
-
-   my @options=('WordPress on This Host');
-   my $wordpress_setup_banner=<<'END';
-
-   ___   ___     (\
-   \  \  \  \     /             _ ____
-    \  \  \  \   / ___  _ __ __| |  _ \ _ __ ___  ___ ___
-     \  \ /\  \ / / _ \| '__/ _` | |_) | '__/ _ \/ __/ __|
-      \  /  \  / | (_) | | | (_| |  __/| | |  __/\__ \__ \
-       \/    \/   \___/|_|  \__,_|_|   |_|  \___||___/___/
-
-
-   Choose the WordPress setup you wish to install on this localhost:
-
-END
-   my %select_wordpress_setup=(
-
-      Name => 'select_wordpress_setup',
+      Name => 'select_php_setup',
       Item_1 => {
 
          Text => ']C[',
          Convey => \@options,
-         #Result => $standup_wordpress,
-	 #Result => $choose_strong_password,
-	 Result => $domain_url,
+	 Result => $standup_php,
 
       },
       Scroll => 1,
-      Banner => $wordpress_setup_banner,
+      Banner => $php_setup_banner,
    );
-   return \%select_wordpress_setup
+   return \%select_php_setup
 
 };
 
